@@ -7,13 +7,11 @@ my @excludes=qw(
   (^|/)images/
   ^src/it/resources/
   ^src/test/resources/
-  ^src/site/resources/styleguides/
   ^src/test/resources-noncompilable/
   /messages.*_..\.properties$
   /releasenotes_old\.xml$
   /releasenotes\.xml$
   /.*_..\.translation[^/]*$
-  /jdk14-test-excluded-files\.list$
 );
 my $exclude = join "|", @excludes;
 while (<>) {
